@@ -36,7 +36,7 @@ def test_creator_xlsx():
         docs = json.load(fin)
         doc = Document(**docs)
         formatter = AFPQualityFormatter()
-        options = AFPQualityParameters(text=False, compare=CompareWith.CREATOR)
+        options = AFPQualityParameters(text=True, compare=CompareWith.CREATOR)
         resp: Response = formatter.format(doc, options)
         assert resp.status_code == 200
         assert (
@@ -45,3 +45,21 @@ def test_creator_xlsx():
         result = Path(testdir, "data/326V7RT.xlsx")
         with result.open("wb") as fout:
             fout.write(resp.body)
+
+
+def test_creator_es_xlsx():
+    testdir = Path(__file__).parent
+    source = Path(testdir, "data/336Y6FE.json")
+    with source.open("r") as fin:
+        docs = json.load(fin)
+        doc = Document(**docs)
+        formatter = AFPQualityFormatter()
+        options = AFPQualityParameters(text=True, compare=CompareWith.CREATOR)
+        resp: Response = formatter.format(doc, options)
+        assert resp.status_code == 200
+        assert (
+            resp.media_type == "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
+        )
+        result = Path(testdir, "data/336Y6FE.xlsx")
+        with result.open("wb") as fout:
+            fout.write(resp.body)
